Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1253)

Unified Diff: third_party/WebKit/Source/platform/graphics/CanvasSurfaceLayerBridge.h

Issue 2811193003: Reintroduce OffscreenCanvasSurfaceClient interface. (Closed)
Patch Set: Add dep on mojom. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/graphics/CanvasSurfaceLayerBridge.h
diff --git a/third_party/WebKit/Source/platform/graphics/CanvasSurfaceLayerBridge.h b/third_party/WebKit/Source/platform/graphics/CanvasSurfaceLayerBridge.h
index fbbf7e5d973471d284b8f3eae33252680f61ba1d..c82436cc6d369947339ce6f063595d1ff85a9b98 100644
--- a/third_party/WebKit/Source/platform/graphics/CanvasSurfaceLayerBridge.h
+++ b/third_party/WebKit/Source/platform/graphics/CanvasSurfaceLayerBridge.h
@@ -8,7 +8,6 @@
#include <memory>
#include "base/memory/ref_counted.h"
#include "base/memory/weak_ptr.h"
-#include "cc/ipc/frame_sink_manager.mojom-blink.h"
#include "cc/surfaces/surface_id.h"
#include "cc/surfaces/surface_reference_factory.h"
#include "mojo/public/cpp/bindings/binding.h"
@@ -34,7 +33,8 @@ class PLATFORM_EXPORT CanvasSurfaceLayerBridgeObserver {
};
class PLATFORM_EXPORT CanvasSurfaceLayerBridge
- : NON_EXPORTED_BASE(public cc::mojom::blink::FrameSinkManagerClient) {
+ : NON_EXPORTED_BASE(
+ public blink::mojom::blink::OffscreenCanvasSurfaceClient) {
public:
explicit CanvasSurfaceLayerBridge(CanvasSurfaceLayerBridgeObserver*,
WebLayerTreeView*);
@@ -43,7 +43,7 @@ class PLATFORM_EXPORT CanvasSurfaceLayerBridge
WebLayer* GetWebLayer() const { return web_layer_.get(); }
const cc::FrameSinkId& GetFrameSinkId() const { return frame_sink_id_; }
// Implementation of cc::mojom::blink::FrameSinkManagerClient
void OnSurfaceCreated(const cc::SurfaceInfo&) override;
void SatisfyCallback(const cc::SurfaceSequence&);
@@ -59,7 +59,7 @@ class PLATFORM_EXPORT CanvasSurfaceLayerBridge
CanvasSurfaceLayerBridgeObserver* observer_;
mojom::blink::OffscreenCanvasSurfacePtr service_;
- mojo::Binding<cc::mojom::blink::FrameSinkManagerClient> binding_;
+ mojo::Binding<blink::mojom::blink::OffscreenCanvasSurfaceClient> binding_;
const cc::FrameSinkId frame_sink_id_;
cc::SurfaceId current_surface_id_;
« no previous file with comments | « content/test/BUILD.gn ('k') | third_party/WebKit/public/platform/modules/offscreencanvas/offscreen_canvas_surface.mojom » ('j') | no next file with comments »
@@ -43,7 +43,7 @@ class PLATFORM_EXPORT CanvasSurfaceLayerBridge
WebLayer* GetWebLayer() const { return web_layer_.get(); }
const cc::FrameSinkId& GetFrameSinkId() const { return frame_sink_id_; }
- // Implementation of cc::mojom::blink::FrameSinkManagerClient
+ // Implementation of blink::mojom::blink::OffscreenCanvasSurfaceClient
void OnSurfaceCreated(const cc::SurfaceInfo&) override;
void SatisfyCallback(const cc::SurfaceSequence&);

Powered by Google App Engine
This is Rietveld 408576698